SystemOrganization addCategory: #'DAO-SatelliteTests'!

TestCase subclass: #BeaconTest
	instanceVariableNames: 'satellite'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-SatelliteTests'!

!BeaconTest methodsFor: 'beacon' stamp: 'EmilianoMenendez 10/24/2013 14:31'!
setUp
	satellite := SatelliteTest satelliteWithAllSubsystems.! !

!BeaconTest methodsFor: 'beacon' stamp: 'EmilianoMenendez 10/27/2013 20:36'!
testCollectingTelemetryShouldIncludeTelemetryForAllSubsystems
	
	| beacon telemetryContainer subsystem |

	beacon := Beacon newFromSubsystems: satellite subsystems.
	
	self assert: beacon data size equals: 5.
	telemetryContainer := beacon data at: 1.
	subsystem := SatelliteTest platformSubsystem.
	self assert: telemetryContainer key equals: subsystem name.
	self assert: telemetryContainer value equals: subsystem telemetry data.
	telemetryContainer := beacon data at: 2.
	subsystem := SatelliteTest memorySubsystem.
	self assert: telemetryContainer key equals: subsystem name.
	self assert: telemetryContainer value equals: subsystem telemetry data.
	telemetryContainer := beacon data at: 3.
	subsystem := SatelliteTest powerSubsystem.
	self assert: telemetryContainer key equals: subsystem name.
	self assert: telemetryContainer value equals: subsystem telemetry data.
	telemetryContainer := beacon data at: 4.
	subsystem := SatelliteTest thermalSubsystem.
	self assert: telemetryContainer key equals: subsystem name.
	self assert: telemetryContainer value equals: subsystem telemetry data.
	telemetryContainer := beacon data at: 5.
	subsystem := SatelliteTest cdhSubsystem.
	self assert: telemetryContainer key equals: subsystem name.
	self assert: telemetryContainer value equals: subsystem telemetry data.
! !

!BeaconTest methodsFor: 'beacon' stamp: 'EmilianoMenendez 10/24/2013 14:30'!
testSerializingBeaconShouldSerializeOK
	
	| beacon bytes |

	beacon := Beacon newFromSubsystems: satellite subsystems.
	
	bytes := beacon serialize.

	self assert: bytes equals: #[255 255 240 0 0 0 0 0 15 66 64 1 0 0 0 100 0 1 0 2 0 3 0 4 0 5 0 6 0 7 0 8 0 9 0 10 0 11 0 12 0 13 0 10 0 20 0 0 0 10 0 0 0 20 30]! !

!BeaconTest methodsFor: 'beacon' stamp: 'EmilianoMenendez 10/24/2013 14:30'!
testSerializingShortBeaconShouldSerializeOK
	
	| beacon bytes |

	beacon := ShortBeacon newFromSubsystems: satellite subsystems.
	
	bytes := beacon serialize.

	self assert: bytes equals: #[255 255 243 10 40]! !

TestCase subclass: #CommandParameterTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-SatelliteTests'!

!CommandParameterTest methodsFor: 'deserialization' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 10/17/2013 14:14'!
testDeserializeNegativeSigned16BitInteger
	| serializedValue parameter streamDeLectura |
	
	serializedValue := #[1 1].
	streamDeLectura := ReadStream on: serializedValue.
	parameter := SignedIntegerCommandParameter newWithName: 'temp' andBitSize: 16.
	
	self assert: parameter name equals: 'temp'.
	self assert: (parameter deserialize: streamDeLectura) equals: -1.! !

!CommandParameterTest methodsFor: 'deserialization' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 10/17/2013 14:15'!
testDeserializePositiveSigned16BitInteger
| serializedValue parameter streamDeLectura |
	
	serializedValue := #[0 1].
	streamDeLectura := ReadStream on: serializedValue.
	parameter := SignedIntegerCommandParameter newWithName: 'temp' andBitSize: 16.
	
	self assert: parameter name equals: 'temp'.
	self assert: (parameter deserialize: streamDeLectura) equals: 1.! !

!CommandParameterTest methodsFor: 'serialization' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 10/17/2013 16:11'!
testSerializeNegativeSigned32BitInteger
	| parameter |
	
	parameter := SignedIntegerCommandParameter newWithName: 'temp' andBitSize: 32.
	parameter value: -1.
	
	self assert: (parameter serialize) equals: #[1 0 0 1].
! !

!CommandParameterTest methodsFor: 'serialization' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 10/17/2013 16:11'!
testSerializePositiveSigned32BitInteger
	| parameter |
	
	parameter := SignedIntegerCommandParameter newWithName: 'temp' andBitSize: 32.
	parameter value: 1.
	
	self assert: (parameter serialize) equals: #[0 0 0 1].
! !

!CommandParameterTest methodsFor: 'serialization' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 10/17/2013 14:16'!
testSerializeString8
	| parameter |
	
	parameter := StringCommandParameter newWithName: 'temp' andBitSize: 8.
	parameter value: 'Hello'.
	
	self assert: (parameter serialize) equals: #[5 72 101 108 108 111].! !

!CommandParameterTest methodsFor: 'serialization' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 10/17/2013 14:16'!
testSerializeUnsigned32BitInteger
	| parameter |
	
	parameter := UnsignedIntegerCommandParameter newWithName: 'temp' andBitSize: 32.
	parameter value: 1.
	
	self assert: (parameter serialize) equals: #[0 0 0 1].! !

TestCase subclass: #CommandRequestTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-SatelliteTests'!

!CommandRequestTest methodsFor: 'serialization' stamp: 'EmilianoMenendez 10/26/2013 16:12'!
testSerializingCommandRequestShouldRecordSerializedBytesIntoCommandRequest
	
	| command commandDefinition subsystem |
	
	commandDefinition := CommandDefinition thermalTelemetry.
	subsystem := SatelliteTest thermalSubsystem.

	command := CommandRequest for: commandDefinition andSubsystem: subsystem withSequenceNumber: 1.

	self assert: command serialize equals: #[1].
	self assert: command bytes equals: #[1].! !

!CommandRequestTest methodsFor: 'serialization' stamp: 'EmilianoMenendez 10/22/2013 15:42'!
testSerializingCommandWithFiveU32ParametersShouldSerializeOK
	
	| command commandDefinition subsystem |
	
	commandDefinition := CommandDefinition memoryReadChunkedAddress.
	subsystem := SatelliteTest memorySubsystem.
	
	command := CommandRequest for: commandDefinition andSubsystem: subsystem withSequenceNumber: 1.

	command addParameterValue: 1.
	command addParameterValue: 2.
	command addParameterValue: 3.
	command addParameterValue: 4.
	command addParameterValue: 5.
	
	self assert: command serialize equals: #[45 0 0 0 1 0 0 0 2 0 0 0 3 0 0 0 4 0 0 0 5]! !

!CommandRequestTest methodsFor: 'serialization' stamp: 'EmilianoMenendez 10/22/2013 15:42'!
testSerializingCommandWithMaxValueSetToOneU24ParameterShouldSerializeOK
	
	| commandDefinition subsystem command  |
	
	commandDefinition := CommandDefinition powerStbSetSwitchesState.
	subsystem := SatelliteTest powerSubsystem.
	
	command := CommandRequest for: commandDefinition andSubsystem: subsystem withSequenceNumber: 1.

	command addParameterValue: 16777215.
	
	self assert: command serialize equals: #[36 255 255 255]! !

!CommandRequestTest methodsFor: 'serialization' stamp: 'EmilianoMenendez 10/22/2013 15:43'!
testSerializingCommandWithMaxValueSetToOneU8ParameterShouldSerializeOK
	
	| command commandDefinition subsystem |
	
	commandDefinition := CommandDefinition platformSetMode.
	subsystem := SatelliteTest platformSubsystem.
	
	command := CommandRequest for: commandDefinition andSubsystem: subsystem withSequenceNumber: 1.

	command addParameterValue: 255.
	
	self assert: command serialize equals: #[32 255]! !

!CommandRequestTest methodsFor: 'serialization' stamp: 'EmilianoMenendez 10/22/2013 15:43'!
testSerializingCommandWithMaxValuesSetToTwoU32ParametersShouldSerializeOK
	
	| command commandDefinition subsystem |
	
	commandDefinition := CommandDefinition memoryReadLongAddress.
	subsystem := SatelliteTest memorySubsystem.

	command := CommandRequest for: commandDefinition andSubsystem: subsystem withSequenceNumber: 1.

	command addParameterValue: 4294967295.
	command addParameterValue: 4294967295.
	
	self assert: command serialize equals: #[44 255 255 255 255 255 255 255 255]! !

!CommandRequestTest methodsFor: 'serialization' stamp: 'EmilianoMenendez 10/22/2013 15:44'!
testSerializingCommandWithOneU24ParameterShouldSerializeOK
	
	| command commandDefinition subsystem |
	
	commandDefinition := CommandDefinition powerStbSetSwitchesState.
	subsystem := SatelliteTest powerSubsystem.

	command := CommandRequest for: commandDefinition andSubsystem: subsystem withSequenceNumber: 1.

	command addParameterValue: 1.
	
	self assert: command serialize equals: #[36 0 0 1]! !

!CommandRequestTest methodsFor: 'serialization' stamp: 'EmilianoMenendez 10/22/2013 15:44'!
testSerializingCommandWithOneU32AndOneString8ParametersShouldSerializeOK
	
	| command commandDefinition subsystem |
	
	commandDefinition := CommandDefinition memoryWriteAddress.
	subsystem := SatelliteTest memorySubsystem.

	command := CommandRequest for: commandDefinition andSubsystem: subsystem withSequenceNumber: 1.

	command addParameterValue: 1.
	command addParameterValue: 'Hello'.
	
	self assert: command serialize = #[33 0 0 0 1 5 72 101 108 108 111]! !

!CommandRequestTest methodsFor: 'serialization' stamp: 'EmilianoMenendez 10/22/2013 15:45'!
testSerializingCommandWithOneU32ParameterShouldSerializeOK
	
	| command commandDefinition subsystem |
	
	commandDefinition := CommandDefinition thermalSetMatrixKey.
	subsystem := SatelliteTest thermalSubsystem.

	command := CommandRequest for: commandDefinition andSubsystem: subsystem withSequenceNumber: 1.

	command addParameterValue: 1.
	
	self assert: command serialize equals: #[32 0 0 0 1]! !

!CommandRequestTest methodsFor: 'serialization' stamp: 'EmilianoMenendez 10/22/2013 15:45'!
testSerializingCommandWithTwoU32ParametersShouldSerializeOK
	
	| command commandDefinition subsystem |
	
	commandDefinition :=CommandDefinition memoryReadLongAddress.
	subsystem := SatelliteTest memorySubsystem.

	command := CommandRequest for: commandDefinition andSubsystem: subsystem withSequenceNumber: 1.

	command addParameterValue: 1.
	command addParameterValue: 2.
	
	self assert: command serialize equals: #[44 0 0 0 1 0 0 0 2]! !

!CommandRequestTest methodsFor: 'serialization' stamp: 'EmilianoMenendez 10/22/2013 15:46'!
testSerializingCommandWithoutParametersShouldSerializeCommandIdOnly
	
	| command commandDefinition subsystem |
	
	commandDefinition := CommandDefinition thermalTelemetry.
	subsystem := SatelliteTest thermalSubsystem.

	command := CommandRequest for: commandDefinition andSubsystem: subsystem withSequenceNumber: 1.

	self assert: command serialize equals: #[1]! !

TestCase subclass: #CommandResponseTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-SatelliteTests'!

!CommandResponseTest methodsFor: 'deserialization' stamp: 'EmilianoMenendez 10/22/2013 17:20'!
testCreatingANewResponseShouldSetTimeOnIt

	| encodedResponse decodedResponse commandDefinition |
	
	"setup"
	"001 sequence number, 0 0 0 1 first element of the response,  then 1 and 2 are the elements of the array"
	encodedResponse := #[0 0 1 0 0 0 1 1 2].

	commandDefinition := CommandDefinition memoryReadLongAddress.
	
	"exercise"	
	decodedResponse := CommandResponse from: encodedResponse using: commandDefinition.
	
	"verify"
	self assert: decodedResponse sequenceNumber equals: 1.
	self deny: decodedResponse time isNil.
! !

!CommandResponseTest methodsFor: 'deserialization' stamp: 'EmilianoMenendez 10/21/2013 19:15'!
testDeserializingArrayOfUnsigned8BitIntegerShouldReturnTheDecodedArray

	| encodedResponse decodedResponse commandDefinition array |
	
	"setup"
	"001 sequence number, 1 first byte, 2 second"
	encodedResponse := #[0 0 1 1 2].

	commandDefinition := CommandDefinition memoryReadAddress.
	
	"exercise"	
	decodedResponse := CommandResponse from: encodedResponse using: commandDefinition.
	
	"verify"
	self assert: decodedResponse sequenceNumber equals: 1.
	self assert: (decodedResponse data size) equals: 1.
	
	array := (decodedResponse data at: 1).
	
	self assert: array size equals: 2.
	self assert: (array at: 1) equals: 1.
	self assert: (array at: 2) equals: 2.

! !

!CommandResponseTest methodsFor: 'deserialization' stamp: 'EmilianoMenendez 10/26/2013 16:09'!
testDeserializingShouldRecordOriginalBytesIntoResponse

	| encodedResponse decodedResponse commandDefinition array firstElement |
	
	"setup"
	"001 sequence number, 0 0 0 1 first element of the response,  then 1 and 2 are the elements of the array"
	encodedResponse := #[0 0 1 0 0 0 1 1 2].

	commandDefinition := CommandDefinition memoryReadLongAddress.
	
	"exercise"	
	decodedResponse := CommandResponse from: encodedResponse using: commandDefinition.
	
	"verify"
	self assert: decodedResponse sequenceNumber equals: 1.

	self assert: (decodedResponse data size) equals: 2.
	
	firstElement := decodedResponse data at: 1.
	self assert: firstElement equals: 1.
	
	array := (decodedResponse data at: 2).
	self assert: array size equals: 2.
	self assert: (array at: 1) equals: 1.
	self assert: (array at: 2) equals: 2.

	self assert: decodedResponse bytes = encodedResponse.! !

!CommandResponseTest methodsFor: 'deserialization' stamp: 'EmilianoMenendez 10/21/2013 19:16'!
testDeserializingThermalNameResponseShouldReturnThermal

	| encodedResponse decodedResponse commandDefinition |

	"001 sequence number, lo que le sigue THERMAL codificado"
	encodedResponse := #[0 0 1 84 72 69 82 77 65 76].
	
	commandDefinition := CommandDefinition getNameCommand.
	
	decodedResponse := CommandResponse from: encodedResponse using: commandDefinition.
	
	self assert: decodedResponse sequenceNumber equals: 1.
	self assert: (decodedResponse data size) equals: 1.
	self assert: (decodedResponse data at: 1) equals: 'THERMAL'.! !

!CommandResponseTest methodsFor: 'deserialization' stamp: 'EmilianoMenendez 10/21/2013 19:16'!
testDeserializingThermalSetMatrixKeyResponseShouldReturnVoid

	| encodedResponse commandDefinition decodedResponse |
	
	"001 sequence number, then empty response"
	encodedResponse := #[0 0 1].
	
	commandDefinition :=  CommandDefinition thermalSetMatrixKey.
	
	decodedResponse := CommandResponse from: encodedResponse using: commandDefinition.
	
	self assert: decodedResponse sequenceNumber equals: 1.
	self assert: (decodedResponse class) equals: VoidCommandResponse.
	
! !

!CommandResponseTest methodsFor: 'deserialization' stamp: 'EmilianoMenendez 10/21/2013 19:16'!
testDeserializingThermalShortTelemetryResponseShouldReturnThermalShortTelemetry

	| encodedResponse commandDefinition decodedResponse |
	
	"001 sequence number, 1 battery temp"
	encodedResponse := #[0 0 1 1].

	commandDefinition :=  CommandDefinition thermalShortTelemetry.
	
	decodedResponse := CommandResponse from: encodedResponse using: commandDefinition.

	self assert: decodedResponse sequenceNumber equals: 1.
	self assert: (decodedResponse data at: 1) equals: 1.
	
! !

!CommandResponseTest methodsFor: 'deserialization' stamp: 'EmilianoMenendez 10/21/2013 19:16'!
testDeserializingThermalTelemetryResponseContainingNegativeNumbersShouldDeserializeOK

	| encodedResponse decodedResponse commandDefinition |
	
	"001 sequence number, 1 1 battery temp, 1 2 radio temp"
	encodedResponse := #[0 0 1 1 1 1 2].

	commandDefinition := CommandDefinition thermalTelemetry.
		
	decodedResponse := CommandResponse from: encodedResponse using: commandDefinition.

	self assert: decodedResponse sequenceNumber equals: 1.
	self assert: (decodedResponse data at: 1) equals: -1.
	self assert: (decodedResponse data at: 2) equals: -2.
! !

!CommandResponseTest methodsFor: 'deserialization' stamp: 'EmilianoMenendez 10/21/2013 19:16'!
testDeserializingThermalTelemetryResponseShouldReturnThermalTelemetry

	| encodedResponse decodedResponse commandDefinition |
	
	"001 sequence number, 0 1 battery temp, 0 2 radio temp"
	encodedResponse := #[0 0 1 0 1 0 2].

	commandDefinition := CommandDefinition thermalTelemetry.
		
	decodedResponse := CommandResponse from: encodedResponse using: commandDefinition.

	self assert: decodedResponse sequenceNumber equals: 1.
	self assert: (decodedResponse data at: 1) equals: 1.
	self assert: (decodedResponse data at: 2) equals: 2.
! !

!CommandResponseTest methodsFor: 'deserialization' stamp: 'EmilianoMenendez 10/21/2013 19:16'!
testDeserializingUsigned32BitIntegerAndArrayOfUnsigned8BitIntegerShouldDeserializeOK

	| encodedResponse decodedResponse commandDefinition array firstElement |
	
	"setup"
	"001 sequence number, 0 0 0 1 first element of the response,  then 1 and 2 are the elements of the array"
	encodedResponse := #[0 0 1 0 0 0 1 1 2].

	commandDefinition := CommandDefinition memoryReadLongAddress.
	
	"exercise"	
	decodedResponse := CommandResponse from: encodedResponse using: commandDefinition.
	
	"verify"
	self assert: decodedResponse sequenceNumber equals: 1.

	self assert: (decodedResponse data size) equals: 2.
	
	firstElement := decodedResponse data at: 1.
	self assert: firstElement equals: 1.
	
	array := (decodedResponse data at: 2).
	self assert: array size equals: 2.
	self assert: (array at: 1) equals: 1.
	self assert: (array at: 2) equals: 2.

! !

TestCase subclass: #ControllerLogFilterCriteriaTest
	instanceVariableNames: 'subsystem command entries'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-SatelliteTests'!

!ControllerLogFilterCriteriaTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendez 11/10/2013 17:05'!
setUp
	| request entry |

	subsystem := SatelliteTest platformSubsystem.

	command := CommandDefinition getNameCommand.

	entries := OrderedCollection new.
	request := CommandRequest for: command andSubsystem: subsystem withSequenceNumber: 1.
	entry := ControllerLogEntry newWithRequest: request.
	entries add: entry.! !

!ControllerLogFilterCriteriaTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendez 11/10/2013 17:05'!
testWhenEvaluatingASelectAllCriteriaThenNoEntryShouldBeFilteredOut
	| criteria filteredEntries |
	
	criteria := SelectAllFilterCriteria new.
	
	filteredEntries := entries select: criteria block.
	self assert: (filteredEntries size) equals: 1.! !

!ControllerLogFilterCriteriaTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendez 11/10/2013 17:06'!
testWhenEvaluatingCriteriaBlockOnEntriesMatchingSubsystemButNotMatchingCommandTheResultingListIsEmpty
	| criteria filteredEntries notMatchingCommand |
	
	notMatchingCommand := CommandDefinition platformTelemetry.
	
	criteria := SubsystemAndCommandFilterCriteria subsystem: subsystem command: notMatchingCommand.
	
	filteredEntries := entries select: criteria block.
	self assert: filteredEntries isEmpty.! !

!ControllerLogFilterCriteriaTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendez 11/10/2013 17:06'!
testWhenEvaluatingCriteriaBlockOnEntriesMatchingTheCriteriaTheResultingListIsNotEmpty
	| criteria filteredEntries |
	
	criteria := SubsystemAndCommandFilterCriteria subsystem: subsystem command: command.
	
	filteredEntries := entries select: criteria block.
	self assert: (filteredEntries size) equals: 1.! !

!ControllerLogFilterCriteriaTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendez 11/10/2013 17:05'!
testWhenEvaluatingCriteriaBlockOnEntriesNotMatchingSubsystemButMatchingCommandTheResultingListIsEmpty
	| criteria filteredEntries notMatchingSubsystem |
	
	notMatchingSubsystem := SatelliteTest thermalSubsystem.
	
	criteria := SubsystemAndCommandFilterCriteria subsystem: notMatchingSubsystem command: command.
	
	filteredEntries := entries select: criteria block.
	self assert: filteredEntries isEmpty.! !

TestCase subclass: #ControllerLogFilterTest
	instanceVariableNames: 'log subsystem command logFilter'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-SatelliteTests'!

!ControllerLogFilterTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendez 11/10/2013 11:00'!
setUp
	log := ControllerLog new.
	logFilter := ControllerLogFilter for: log.
	subsystem := SatelliteTest platformSubsystem.
	command := CommandDefinition getNameCommand.! !

!ControllerLogFilterTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendez 11/10/2013 11:05'!
testWhenApplyingFilterWithCriteriaMatchingSomeEntriesTheResultContainsTheMatchingEntries
	| request filteredEntries criteria telemetryCommand |

	telemetryCommand := CommandDefinition platformTelemetry.
	
	(1 to: 2) do: [ :number |
		request := CommandRequest for: command andSubsystem: subsystem withSequenceNumber: number.
		log logRequest: request.
	].

	request := CommandRequest for: telemetryCommand andSubsystem: subsystem withSequenceNumber: 3.
	log logRequest: request.
	
	"exercise"
	criteria := SubsystemAndCommandFilterCriteria subsystem: subsystem command: command.
	filteredEntries := logFilter apply: criteria.
	
	"verify"
	self assert: (filteredEntries size) equals: 2.
	filteredEntries do: [ :entry | self assert: entry commandName equals: command commandName ].
! !

!ControllerLogFilterTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendez 11/10/2013 11:01'!
testWhenApplyingFilterWithCriteriaNotMatchingEntriesTheResultShouldBeEmpty
	| request filteredEntries criteria telemetryCommand|

	telemetryCommand := CommandDefinition platformTelemetry.
	
	request := CommandRequest for: telemetryCommand andSubsystem: subsystem withSequenceNumber: 1.
	log logRequest: request.
	
	"exercise"
	criteria := SubsystemAndCommandFilterCriteria subsystem: subsystem command: command.
	filteredEntries := logFilter apply: criteria.
	
	"verify"
	self assert: filteredEntries isEmpty.
! !

TestCase subclass: #ControllerLogTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-SatelliteTests'!

!ControllerLogTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/17/2013 23:13'!
testWhenAskingForASequenceNumberNotLoggedTheResultShouldBeFalse
	| log |
	
	log := ControllerLog new.
	
	self deny: (log containsEntryWithSequenceNumber: 1)
! !

!ControllerLogTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendez 10/26/2013 17:38'!
testWhenLoggingABeaconTheLogEntryShouldContainBeaconName
	| log beaconDefinition beacon data logEntry |
	
	"setup"
	log := ControllerLog new.
	
	beaconDefinition := CommandDefinition beacon.
	
	data := OrderedCollection new.
	data add: 'BLAH'.
	beacon := DataCommandResponse for: beaconDefinition withSequenceNumber: 16rFFFFF0 andData: data.
	
	"exercise"
	log logResponse: beacon.
	
	"verify"
	logEntry := log entries first.
	self assert: logEntry commandName equals: beaconDefinition commandName.

! !

!ControllerLogTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendez 10/26/2013 16:19'!
testWhenLoggingABeaconTheLogEntryShouldContainOnlyTheBeacon
	| log beaconDefinition beacon data logEntry |
	
	"setup"
	log := ControllerLog new.
	
	beaconDefinition := CommandDefinition beacon.
	
	data := OrderedCollection new.
	data add: 'BLAH'.
	beacon := DataCommandResponse for: beaconDefinition  withSequenceNumber: 16rFFFFF0 andData: data.
	
	"exercise"
	log logResponse: beacon.
	
	"verify"
	self assert: log entries isEmpty not.
	logEntry := log entries first.
	self assert: (logEntry response) equals: beacon.
! !

!ControllerLogTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendez 10/27/2013 22:52'!
testWhenLoggingABeaconTheLogEntryShouldContainTheCorrespondingBytes
	| log beacon logEntry |
	
	"setup"
	log := ControllerLog new.
	
	beacon := SatelliteTest beacon.
	
	"exercise"
	log logResponse: beacon.
	
	"verify"
	self assert: log entries isEmpty not.
	logEntry := log entries first.
	self assert: (logEntry response) equals: beacon.
	self assert: (logEntry response bytes) equals: #[255 255 240 0 0 0 0 0 15 66 64 1 0 0 0 100 0 1 0 2 0 3 0 4 0 5 0 6 0 7 0 8 0 9 0 10 0 11 0 12 0 13 0 10 0 20 0 0 0 10 0 0 0 20 30].
! !

!ControllerLogTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendez 10/26/2013 17:38'!
testWhenLoggingARequestTheLogEntryShouldContainCommandName
	| log commandDefinition request logEntry |
	
	log := ControllerLog new.

	commandDefinition := CommandDefinition getNameCommand.
	request := CommandRequest for: commandDefinition andSubsystem: SatelliteTest platformSubsystem withSequenceNumber: 1.
	
	"exercise"
	log logRequest: request.
	
	logEntry := log entryWithSequenceNumber: 1.
	self assert: logEntry commandName equals: commandDefinition commandName.
! !

!ControllerLogTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendez 10/22/2013 15:47'!
testWhenLoggingARequestTheLogEntryShouldContainTheCorrespondingBytes
	| log entry request |
	
	log := ControllerLog new.
	
	request := CommandRequest for: CommandDefinition getNameCommand andSubsystem: SatelliteTest platformSubsystem withSequenceNumber: 1.
	
	"exercise"
	log logRequest: request.
	
	"verify"
	entry := log entryWithSequenceNumber: 1.
	"its only serializing the request, without sequence number and target subsystem"
	self assert: entry requestBytes equals: #[0].! !

!ControllerLogTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendez 10/22/2013 15:47'!
testWhenLoggingARequestTheSequenceNumberIsLogged
	| log request |
	
	log := ControllerLog new.
	
	request := CommandRequest for: CommandDefinition getNameCommand andSubsystem: SatelliteTest platformSubsystem withSequenceNumber: 1.
	
	"exercise"
	log logRequest: request.
	
	self assert: (log containsEntryWithSequenceNumber: 1).
! !

!ControllerLogTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendez 10/22/2013 15:47'!
testWhenLoggingARequestUsingAnExistingSequenceNumberShouldArchiveTheOriginalRequest
	"log using a sequence number and then log again using the same sequence number, to make the log archive the first entry"
	| log newLogEntry logEntryForArchiving archivedLogEntry requestToBeArchived commandDefinition newRequest |
	
	"setup"
	log := ControllerLog new.
	commandDefinition := CommandDefinition getNameCommand.
	requestToBeArchived := CommandRequest for: commandDefinition andSubsystem: SatelliteTest platformSubsystem withSequenceNumber: 1.
	log logRequest: requestToBeArchived.
	self assert: (log containsEntryWithSequenceNumber: 1).
	logEntryForArchiving := log entryWithSequenceNumber: 1.
	
	"exercise"
	"this should archive the first entry"
	newRequest := CommandRequest for: commandDefinition andSubsystem: SatelliteTest platformSubsystem withSequenceNumber: 1.
	log logRequest: newRequest.
	
	"verify"
	newLogEntry := log entryWithSequenceNumber: 1.
	self assert: (newLogEntry request) equals: newRequest.
	archivedLogEntry := log archive at: 1.
	self assert: archivedLogEntry equals: logEntryForArchiving.

! !

!ControllerLogTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendez 10/22/2013 15:48'!
testWhenLoggingAResponseUsingAnExistingSequenceNumberTheLogEntryShouldContainTheRequestAndTheResponse
	| log logEntry commandDefinition request response |
	
	"setup"
	log := ControllerLog new.
	commandDefinition := CommandDefinition getNameCommand.
	request := CommandRequest for: commandDefinition andSubsystem: SatelliteTest platformSubsystem withSequenceNumber: 1.
	log logRequest: request .
		
	"exercise"
	response := DataCommandResponse for: commandDefinition withSequenceNumber: 1 andData: nil.
	log logResponse: response.
	
	"verify"
	logEntry := log entryWithSequenceNumber: 1.
	self assert: (logEntry request) equals: request.
	self assert: (logEntry response) equals: response.
! !

!ControllerLogTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendez 10/26/2013 17:30'!
testWhenLoggingTwoBeaconsTheLogShouldContainBoth
	| log beaconDefinition beacon data logEntry data2 beacon2 |
	
	"setup"
	log := ControllerLog new.
	
	beaconDefinition := CommandDefinition beacon.
	
	data := OrderedCollection new.
	data add: 'beacon1'.
	beacon := DataCommandResponse for: beaconDefinition withSequenceNumber: 16rFFFFF0 andData: data.

	data2 := OrderedCollection new.
	data2 add: 'beacon2'.
	beacon2 := DataCommandResponse for: beaconDefinition withSequenceNumber: 16rFFFFF0 andData: data2 .

	"exercise"
	log logResponse: beacon.
	log logResponse: beacon2.
	
	"verify"
	self assert: log entries isEmpty not.
	logEntry := log entries first.
	self assert: (logEntry response data) equals: beacon data.
	logEntry := log entries second.
	self assert: (logEntry response data) equals: beacon2 data.
! !

TestCase subclass: #PackageDiscardRuleTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-SatelliteTests'!

!PackageDiscardRuleTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendez 10/20/2013 14:04'!
testCheckingACorrectBeaconShouldInvalidateTheRule
	| rule |

	rule := PackageDiscardRule wrongBeacon.

	self deny: (rule check: #[255 255 240 67 117 98 101 66 117 103 45 49 32 116 111 32 101 97 114 116 104 44 32 97 99 97 32 118 97 32 101 108 32 67 97 112 105 116 97 110 32 66 101 116 111 32 102 108 97 99 111 33 0]).! !

!PackageDiscardRuleTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendez 10/20/2013 14:06'!
testPassingAPackageWithUniqueSequenceNumberShouldInvalidateTheRule
	| rule |

	rule := PackageDiscardRule repeatedSequenceNumber.

	self deny: (rule check: #[0 0 1 1 2 3 4 5]).! !

!PackageDiscardRuleTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendez 10/20/2013 14:05'!
testPassingARepeatedSequenceNumberPackageShouldValidateTheRule
	| rule |

	rule := PackageDiscardRule repeatedSequenceNumber.

	self assert: (rule check: #[0 0 1 254]).! !

!PackageDiscardRuleTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendez 10/20/2013 14:00'!
testPassingAWrongBeaconShouldDiscardTheBeacon
	| rule |

	rule := PackageDiscardRule wrongBeacon.

	self assert: (rule check: #[255 255 241 67 117 98 101 66 117 103 45 49 32 116 111 32 101 97 114 116 104 44 32 97 99 97 32 118 97 32 101 108 32 67 97 112 105 116 97 110 32 66 101 116 111 32 102 108 97 99 111 33 0]).! !

TestCase subclass: #SatelliteControllerIntegrationTest
	instanceVariableNames: 'satelliteController radio'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-SatelliteTests'!

!SatelliteControllerIntegrationTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendez 10/25/2013 16:53'!
setUp
	radio := SatelliteControllerRadio connectTo: #[127 0 1 1] port: 4445.
	satelliteController := SatelliteController newWith: radio.
! !

!SatelliteControllerIntegrationTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendez 10/25/2013 16:11'!
tearDown 
	satelliteController shutdown! !

!SatelliteControllerIntegrationTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendez 11/3/2013 20:15'!
testReceiveABeacon
	| messageHistory messages beacon beaconDefinition beaconLogEntry platformTelemetry |

	"exercise"
	messageHistory := [satelliteController log] 
					ensure: [satelliteController shutdown].

	"verify"
	messages := messageHistory entries.
	beaconDefinition := CommandDefinition beacon.
	beaconLogEntry := messages detect: [:message | message sequenceNumber = beaconDefinition id].
	beacon := beaconLogEntry response.
	self deny: beacon isNil.
	self assert: beacon data isEmpty not.
	"PLATFORM telemetry"
	platformTelemetry := (beacon data at: 1) value.
	self deny: platformTelemetry isNil.
	self deny: platformTelemetry isEmpty.
	self assert: (platformTelemetry at: 1) key equals: 'tickCount'.
	self deny: (platformTelemetry at: 1) value isNil.
	self assert: (platformTelemetry at: 2) key equals: 'currentMode'.
	self deny: (platformTelemetry at: 2) value isNil.
! !

!SatelliteControllerIntegrationTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendez 11/3/2013 20:21'!
testReceiveAShortBeacon
	| messageHistory messages shortBeaconDefinition shortBeaconLogEntry shortBeacon thermalTelemetry cdhTelemetry |

	"exercise"
	messageHistory := [satelliteController log] 
					ensure: [satelliteController shutdown].

	"verify"
	shortBeaconDefinition := CommandDefinition shortBeacon.
	messages := messageHistory entries.
	shortBeaconLogEntry := messages detect: [:message | message sequenceNumber = shortBeaconDefinition id].
	shortBeacon := shortBeaconLogEntry response.
	
	self assert: (shortBeacon data at: 1) key equals: 'THERMAL'.
	thermalTelemetry := (shortBeacon data at: 1) value.
	self deny: thermalTelemetry isNil.
	self assert: thermalTelemetry size equals: 1.
	self assert: (thermalTelemetry at: 1) key equals: 'battery_temp'.
	self deny: (thermalTelemetry at: 1) value isNil.

	self assert: (shortBeacon data at: 2) key equals: 'CDH'.
	cdhTelemetry := (shortBeacon data at: 2) value.
	self deny: cdhTelemetry isNil.
	self assert: cdhTelemetry size equals: 1.
	self assert: (cdhTelemetry at: 1) key equals: 'ticksLow'.
	self deny: (cdhTelemetry at: 1) value isNil.
! !

!SatelliteControllerIntegrationTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendez 10/25/2013 16:05'!
testSendingAGetNameCommandShouldGetResponseBack
	| commandDefinition data thermalSubsystem response |

	"setup"	
	thermalSubsystem := SatelliteTest thermalSubsystem.
	commandDefinition := CommandDefinition getNameCommand.
	data := OrderedCollection new.
	
	"exercise"
	[response := satelliteController sendCommand: commandDefinition toSubsystem: thermalSubsystem withData: data.

	"verify"
	self deny: response isNil.
	self assert: response data size equals: 1.
	self assert: (response data at: 1) key equals: 'name'.
	self assert: (response data at: 1) value equals: 'THERMAL'.
	] ensure: [satelliteController shutdown]
	! !

!SatelliteControllerIntegrationTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendez 10/25/2013 16:44'!
testSendingAReadMemoryCommandShouldGetResponseBack
	| commandDefinition subsystem parameters response |

	"setup"	
	commandDefinition := CommandDefinition memoryReadAddress.
	subsystem := SatelliteTest memorySubsystem.

	parameters := OrderedCollection new.
	parameters add: 1.
	
	"exercise"
	[response := satelliteController sendCommand: commandDefinition toSubsystem: subsystem withData: parameters.

	"verify"
	self deny: response isNil.
	self assert: response data size equals: 1.
	self assert: (response data at: 1) key equals: 'data'.
	self assert: (response data at: 1) value equals: 'ASDF'.
	] ensure: [satelliteController shutdown]
	! !

TestCase subclass: #SatelliteControllerMessageCodecTest
	instanceVariableNames: 'messageCodec'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-SatelliteTests'!

!SatelliteControllerMessageCodecTest methodsFor: 'serialization' stamp: 'EmilianoMenendez 10/24/2013 16:57'!
setUp
	messageCodec := SatelliteControllerMessageCodec new.! !

!SatelliteControllerMessageCodecTest methodsFor: 'deserialization' stamp: 'EmilianoMenendez 10/24/2013 16:57'!
testDeserealizeBeacon
	| expectedBeacon serializedBeacon beacon |

	"setup"
	serializedBeacon := #[255 255 240 0 0 0 0 0 15 66 64 1 0 0 0 100 0 1 0 2 0 3 0 4 0 5 0 6 0 7 0 8 0 9 0 10 0 11 0 12 0 13 0 10 0 20 0 0 0 10 0 0 0 20 30].	
	expectedBeacon := SatelliteTest beacon.
	
	"exercise"
	beacon := messageCodec deserialize: serializedBeacon.

	"verify"
	self assert: beacon equals: expectedBeacon.
! !

!SatelliteControllerMessageCodecTest methodsFor: 'deserialization' stamp: 'EmilianoMenendez 10/24/2013 16:57'!
testDeserealizeShortBeacon
	|expectedBeacon serializedBeacon beacon |

	"setup"
	expectedBeacon := SatelliteTest shortBeacon.
	serializedBeacon := #[255 255 243 10 40].

	"exercise"	
	beacon := messageCodec deserialize: serializedBeacon.

	"verify"
	self assert: beacon equals: expectedBeacon.
! !

!SatelliteControllerMessageCodecTest methodsFor: 'deserialization' stamp: 'EmilianoMenendez 10/26/2013 16:14'!
testDeserealizingABeaconShouldRecordSerializedBytesIntoBeacon
	| expectedBeacon serializedBeacon beacon |

	"setup"
	serializedBeacon := #[255 255 240 0 0 0 0 0 15 66 64 1 0 0 0 100 0 1 0 2 0 3 0 4 0 5 0 6 0 7 0 8 0 9 0 10 0 11 0 12 0 13 0 10 0 20 0 0 0 10 0 0 0 20 30].	
	expectedBeacon := SatelliteTest beacon.
	
	"exercise"
	beacon := messageCodec deserialize: serializedBeacon.

	"verify"
	self assert: beacon equals: expectedBeacon.
	self assert: beacon bytes equals: serializedBeacon.! !

!SatelliteControllerMessageCodecTest methodsFor: 'serialization' stamp: 'EmilianoMenendez 10/24/2013 16:57'!
testSerializingNameCommandRequestShouldReturnCorrectString

	| commandDefinition commandRequest resultingByteArray platformSubsystem sequenceNumber |
	
	"setup"
	commandDefinition :=  CommandDefinition getNameCommand.
	platformSubsystem := SatelliteTest platformSubsystem.
	commandRequest := CommandRequest for: commandDefinition andSubsystem: platformSubsystem withSequenceNumber: 1.

	sequenceNumber := SequenceNumber new.
	sequenceNumber next.

	"exercise"
	resultingByteArray := messageCodec serializeRequest: commandRequest.
	
	"verify"
	self assert: resultingByteArray equals: #[119 167 33 0 0 1 0 0]! !

!SatelliteControllerMessageCodecTest methodsFor: 'serialization' stamp: 'EmilianoMenendez 10/24/2013 16:58'!
testSerializingSetMatrixKeyRequestShouldReturnCorrectString

	| commandRequest resultingByteArray thermalSubsystem commandDefinition sequenceNumber |

	"setup"	
	commandDefinition :=  CommandDefinition thermalSetMatrixKey.
	thermalSubsystem := SatelliteTest thermalSubsystem.
	
	commandRequest := CommandRequest for: commandDefinition andSubsystem: thermalSubsystem withSequenceNumber: 1.
	commandRequest addParameterValue: 1.

	sequenceNumber := SequenceNumber new.
	sequenceNumber next.
	
	"exercise"	
	resultingByteArray := messageCodec serializeRequest: commandRequest.
	
	"verify"
	self assert: resultingByteArray equals:  #[50 108 238 0 0 1 3 32 0 0 0 1]! !

!SatelliteControllerMessageCodecTest methodsFor: 'serialization' stamp: 'EmilianoMenendez 10/24/2013 16:58'!
testSerializingTelemetryRequestShouldReturnCorrectString

	| commandRequest resultingByteArray thermalSubsystem commandDefinition sequenceNumber |

	"setup"	
	commandDefinition := CommandDefinition thermalTelemetry.
	thermalSubsystem := SatelliteTest thermalSubsystem.

	commandRequest := CommandRequest for: commandDefinition andSubsystem: thermalSubsystem withSequenceNumber: 1.

	sequenceNumber := SequenceNumber new.
	sequenceNumber next.

	"exercise"	
	resultingByteArray := messageCodec serializeRequest: commandRequest.

	"verify"
	self assert: resultingByteArray equals: #[151 148 145 0 0 1 3 1]! !

!SatelliteControllerMessageCodecTest methodsFor: 'deserialization' stamp: 'EmilianoMenendez 10/24/2013 23:06'!
testTryingToDeserializeAPackageWithoutARegisteredSequenceNumberShouldThrowAnError
	
	self should: [messageCodec deserialize: #[0 0 1 0 0]] 
		raise: Error
		whoseDescriptionIncludes: SatelliteControllerMessageCodec commandDefinitionNotRegisteredForSequenceNumberErrorMessage 
		description: 'Method should throw an Exception'.
! !

TestCase subclass: #SatelliteControllerTest
	instanceVariableNames: 'satellite radio satelliteController'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-SatelliteTests'!

!SatelliteControllerTest methodsFor: 'initialization' stamp: 'EmilianoMenendez 10/25/2013 16:51'!
setUp
	satellite := SatelliteTest satelliteWithAllSubsystems.
	radio := SatelliteControllerRadioStub connectTo: satellite.
	satelliteController := SatelliteController newWith: radio.
! !

!SatelliteControllerTest methodsFor: 'messaging' stamp: 'EmilianoMenendez 10/24/2013 11:13'!
testReceivingAPackageFromRadioShouldDecodeMessage

	| expectedBeacon beaconPackage log |

	"setup"
	beaconPackage := SatelliteControllerRadioStub beaconPackage.
	expectedBeacon := SatelliteTest beacon.

	"exercise"
	radio sendToController: beaconPackage.

	"verify"	
	log := satelliteController log.
	
	self assert: log entries size equals: 1.
	self assert: (log entries at: 1) response data equals: expectedBeacon data.
! !

!SatelliteControllerTest methodsFor: 'messaging' stamp: 'EmilianoMenendez 10/27/2013 22:37'!
testReceivingAPackageFromRadioShouldLogEntryWithDecodedMessage

	| beaconPackage expectedBeacon log |

	beaconPackage := SatelliteControllerRadioStub beaconPackage.
	
	expectedBeacon := SatelliteTest beacon.

	"exercise"
	radio sendToController: beaconPackage.

	log := satelliteController log.
	self assert: log entries size equals: 1.
	self assert: (log entries at: 1) response data equals: expectedBeacon data.
	self assert: (log entries at: 1) response bytes equals: #[255 255 240 0 0 0 0 0 15 66 64 1 0 0 0 100 0 1 0 2 0 3 0 4 0 5 0 6 0 7 0 8 0 9 0 10 0 11 0 12 0 13 0 10 0 20 0 0 0 10 0 0 0 20 30].
! !

!SatelliteControllerTest methodsFor: 'messaging' stamp: 'EmilianoMenendez 10/24/2013 12:18'!
testReceivingARepeatedSequenceNumberFromRadioShouldBeIgnored

	| log wrongPackage |

	"the sequence number 0 0 1 marked as repeated"
	wrongPackage := #[0 0 1 254].

	"exercise"
	radio sendToController: wrongPackage.

	log := satelliteController log.
	
	self assert: log entries size equals: 0.
! !

!SatelliteControllerTest methodsFor: 'messaging' stamp: 'EmilianoMenendez 10/24/2013 12:19'!
testReceivingAWrongBeaconFromRadioShouldBeIgnored

	| wrongPackage log |

	"a wrong beacon has a header 255 255 241"
	wrongPackage := #[255 255 241 0 0 0 0 0 0 134 147 3 0 0 77 68 0 0 138 208 0 0 0 0 0 30 0 60 0 0 0 0 64 230 153 154 255 252 255 255 138 208 255 255 255 255 0 0 0 1 0 0 0 0 128 0 0 0 0 0 0 0 0 0 0 0 0 1 58].

	"exercise"
	radio sendToController: wrongPackage.

	"verify"
	log := satelliteController log.
		
	self assert: log entries size equals: 0.
! !

TestCase subclass: #SatelliteTest
	instanceVariableNames: 'satellite radio satelliteController messageCodec'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-SatelliteTests'!

!SatelliteTest class methodsFor: 'beacon' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 10/17/2013 23:26'!
beacon

	| satellite |

	satellite := self satelliteWithAllSubsystems.
	
	^ Beacon newFromSubsystems: satellite subsystems.! !

!SatelliteTest class methodsFor: 'beacon' stamp: 'EzequielDavidovichCaballero 10/2/2013 22:34'!
cdhSubsystem
	| cdhSubsystem |

	cdhSubsystem := Subsystem cdh.
	cdhSubsystem setAttribute: 'lastSeenSequenceNumber' withValue: 10.
	cdhSubsystem setAttribute: 'nextBeaconEnableTicks' withValue: 20.
	cdhSubsystem setAttribute: 'antennaDeployStatus' withValue: 30.
	cdhSubsystem setAttribute: 'ticksLow' withValue: 40.
	
	^ cdhSubsystem! !

!SatelliteTest class methodsFor: 'beacon' stamp: 'EzequielDavidovichCaballero 10/2/2013 22:34'!
memorySubsystem
	| memorySub |

	memorySub := Subsystem memory.
	memorySub setAttribute: 'free' withValue: 100.
	
	^ memorySub! !

!SatelliteTest class methodsFor: 'beacon' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 10/17/2013 15:33'!
platformSubsystem
	| platformSub |

	platformSub := Subsystem platform.
	platformSub setAttribute: 'tickCount' withValue: 1000000.
	platformSub setAttribute: 'currentMode' withValue: 1.
	
	^ platformSub! !

!SatelliteTest class methodsFor: 'beacon' stamp: 'EzequielDavidovichCaballero 10/2/2013 22:34'!
powerSubsystem
	| powerSubsystem |

	powerSubsystem := Subsystem power.

	powerSubsystem setAttribute: 'low_voltage_counter' withValue: 1.
	powerSubsystem setAttribute: 'battery_v' withValue: 2.
	powerSubsystem setAttribute: 'array_X_v' withValue: 3.
	powerSubsystem setAttribute: 'array_Xp_mA' withValue: 4.
	powerSubsystem setAttribute: 'array_Xm_mA' withValue: 5.
	powerSubsystem setAttribute: 'array_Y_v' withValue: 6.
	powerSubsystem setAttribute: 'array_Yp_mA' withValue: 7.
	powerSubsystem setAttribute: 'array_Y_mA' withValue: 8.
	powerSubsystem setAttribute: 'array_Z_v' withValue: 9.
	powerSubsystem setAttribute: 'array_Zp_mA' withValue: 10.
	powerSubsystem setAttribute: 'array_Zm_mA' withValue: 11.
	powerSubsystem setAttribute: '_3v3_mA' withValue: 12.
	powerSubsystem setAttribute: '_5v_mA' withValue: 13.
	
	^ powerSubsystem! !

!SatelliteTest class methodsFor: 'beacon' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 10/13/2013 18:39'!
satelliteWithAllSubsystems
	| subsystems |

	subsystems := OrderedCollection new.
	
	subsystems add: self platformSubsystem.
	subsystems add: self memorySubsystem.
	subsystems add: self powerSubsystem.
	subsystems add: self thermalSubsystem.
	subsystems add: self cdhSubsystem.

	^ Satellite newWithSubsystems: subsystems.
! !

!SatelliteTest class methodsFor: 'beacon' stamp: 'EmilianoMenendez 10/27/2013 21:21'!
shortBeacon

	| subsystems |

	subsystems := OrderedCollection new.
	subsystems add: SatelliteTest thermalSubsystem.
	subsystems add: SatelliteTest cdhSubsystem.
	
	^ ShortBeacon newFromSubsystems: subsystems.! !

!SatelliteTest class methodsFor: 'beacon' stamp: 'EzequielDavidovichCaballero 10/2/2013 22:34'!
thermalSubsystem
	| thermalSub |

	thermalSub := Subsystem thermal.
	thermalSub setAttribute: 'battery_temp' withValue: 10.
	thermalSub setAttribute: 'radio_temp' withValue: 20.
	
	^ thermalSub! !

!SatelliteTest methodsFor: 'beacon' stamp: 'EmilianoMenendez 10/24/2013 16:58'!
setUp
	satellite := SatelliteTest satelliteWithAllSubsystems.
	radio := SatelliteControllerRadioStub connectTo: satellite.
	satelliteController := SatelliteControllerStub newWith: radio.
	messageCodec := SatelliteControllerMessageCodec new.! !

!SatelliteTest methodsFor: 'beacon' stamp: 'EmilianoMenendez 10/27/2013 21:12'!
testEmittingABeaconShouldReturnCollectedTelemetry

	| beacon expectedBeaconData subsystemsOrderedById |

	"setup"
	subsystemsOrderedById := SortedCollection sortBlock: [ :current :new | current id < new id ].
	subsystemsOrderedById addAll: satellite subsystems.

	expectedBeaconData :=  OrderedCollection new.
	
	subsystemsOrderedById do: [ :subsystem | expectedBeaconData add: (Association key: subsystem name value: subsystem telemetry data) ].

	"exercise"	
	beacon := satellite emitBeacon.

	"verify"	
	self assert: beacon data equals: expectedBeaconData.
! !

!SatelliteTest methodsFor: 'beacon' stamp: 'EmilianoMenendez 10/27/2013 21:12'!
testEmittingAShortBeaconShouldReturnCollectedShortTelemetry

	| beacon expectedBeaconData subsystemsOrderedById |

	"setup"
	subsystemsOrderedById := SortedCollection sortBlock: [ :current :new | current id < new id ].
	subsystemsOrderedById addAll: satellite subsystems.
	
	expectedBeaconData :=  OrderedCollection new.
	
	subsystemsOrderedById do: [ :subsystem | expectedBeaconData add: (Association key: subsystem name value: subsystem shortTelemetry data) ].
	
	"exercise"	
	beacon := satellite emitShortBeacon.

	"verify"	
	self assert: beacon data equals: expectedBeaconData.
! !

TestCase subclass: #SequenceNumberTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-SatelliteTests'!

!SequenceNumberTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendez 10/20/2013 10:56'!
test1AsByteArray
	| sequenceNumber |

	sequenceNumber := SequenceNumber new.

	sequenceNumber next.

	self assert: sequenceNumber asByteArray equals: #[0 0 1].! !

!SequenceNumberTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/21/2013 15:50'!
testLastSequenceNumberAsByteArray
	| sequenceNumber lastNumber |
	
	lastNumber := LargePositiveInteger readFrom: 'FFFFF0' base: 16.

	sequenceNumber := SequenceNumber startingFrom: lastNumber.

	self assert: sequenceNumber asByteArray equals: #[255 255 240].! !

!SequenceNumberTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendez 10/20/2013 10:57'!
testNewSequenceNumberStartsIn1
	| sequenceNumber |
	
	sequenceNumber := SequenceNumber new.
	
	sequenceNumber next.

	self assert: sequenceNumber current equals: 1! !

!SequenceNumberTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/21/2013 15:50'!
testNextOfLastNumberIs1
	| lastNumber sequenceNumber one |
	
	lastNumber := LargePositiveInteger readFrom: 'FFFFEF' base: 16.
	sequenceNumber := SequenceNumber startingFrom: lastNumber.
	one := sequenceNumber next.
	
	self assert: one equals: 1! !

TestCase subclass: #SubsystemTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-SatelliteTests'!

!SubsystemTest methodsFor: 'subsystem' stamp: 'EzequielDavidovichCaballero 10/2/2013 22:34'!
test01WhenCreatingASubsystemTheIdAndNameIsSet

	| subsystem |

	"setup"
	subsystem := Subsystem memory.

	"verify"	
	self assert: subsystem id equals: 1.
	self assert: subsystem name equals: 'MEMORY'.
! !

!SubsystemTest methodsFor: 'subsystem' stamp: 'EmilianoMenendez 11/4/2013 13:12'!
test02WhenCreatingASubsystemItCanAnswerBasicCommands

	| subsystem |

	"setup"
	subsystem := Subsystem thermal.

	"verify"	
	self assert: (subsystem understands: 'name').
	self assert: (subsystem understands: 'telemetry').
	self assert: (subsystem understands: 'shortTelemetry').
! !

!SubsystemTest methodsFor: 'subsystem' stamp: 'EzequielDavidovichCaballero 10/2/2013 22:34'!
test03WhenCreatingASubsystemItDoesntUnderstandUnknwonCommand

	| subsystem  |

	"setup"
	subsystem := Subsystem memory.

	"verify"	
	self deny: (subsystem understands: 'notACommand').
! !

!SubsystemTest methodsFor: 'subsystem' stamp: 'EmilianoMenendez 10/22/2013 15:32'!
test04ThermalShortTelemetryShouldReturnOK

	| subsystem expectedShortTelemetry shortTelemetry data |

	"setup"
	subsystem := SatelliteTest thermalSubsystem.
	data := OrderedCollection new.
	data add: (Association key: 'battery_temp' value: 10).
	expectedShortTelemetry := DataCommandResponse for: CommandDefinition thermalShortTelemetry withSequenceNumber: 0 andData: data.
	
	"excercise"
	shortTelemetry:=	subsystem shortTelemetry. 

	"verify"	
	self assert: shortTelemetry = expectedShortTelemetry.

! !

!SubsystemTest methodsFor: 'subsystem' stamp: 'EmilianoMenendez 10/22/2013 15:32'!
test05ThermalTelemetryShouldReturnOK

	| subsystem expectedTelemetry telemetry data |

	"setup"
	subsystem := SatelliteTest thermalSubsystem.
	data := OrderedCollection new.
	data add: (Association key: 'battery_temp' value: 10).
	data add: (Association key: 'radio_temp' value: 20).
	expectedTelemetry := DataCommandResponse for: CommandDefinition thermalTelemetry withSequenceNumber: 0 andData: data.
	
	"excercise"
	telemetry:= subsystem telemetry. 

	"verify"	
	self assert: telemetry = expectedTelemetry.

! !

SatelliteController subclass: #SatelliteControllerStub
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-SatelliteTests'!

!SatelliteControllerStub class methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendez 10/24/2013 14:33'!
newWith: aSatelliteControllerRadioStub 
	^ self new initializeWith: aSatelliteControllerRadioStub! !

!SatelliteControllerStub methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendez 10/24/2013 14:29'!
receive: aByteArray
	"do nothing"
! !

Object subclass: #SatelliteControllerRadioStub
	instanceVariableNames: 'controller satellite packages'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-SatelliteTests'!

!SatelliteControllerRadioStub class methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 10/18/2013 18:19'!
beaconPackage
	^ #[255 255 240 0 0 0 0 0 15 66 64 1 0 0 0 100 0 1 0 2 0 3 0 4 0 5 0 6 0 7 0 8 0 9 0 10 0 11 0 12 0 13 0 10 0 20 0 0 0 10 0 0 0 20 30].! !

!SatelliteControllerRadioStub class methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 10/19/2013 12:30'!
connectTo: aSatellite
	^ self new initializeWithSatellite: aSatellite.! !

!SatelliteControllerRadioStub methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendez 10/25/2013 16:28'!
connect
	"do nothing"! !

!SatelliteControllerRadioStub methodsFor: 'messaging' stamp: 'EmilianoMenendez 10/24/2013 11:54'!
controller: aSatelliteController
	controller := aSatelliteController! !

!SatelliteControllerRadioStub methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendez 10/23/2013 19:19'!
incomingPackages
	^ packages removeFirst: packages size.! !

!SatelliteControllerRadioStub methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 10/19/2013 12:29'!
initializeWithSatellite: aSatellite
	satellite := aSatellite.
	satellite radio: self.
	packages := OrderedCollection new.! !

!SatelliteControllerRadioStub methodsFor: 'messaging' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 10/19/2013 13:41'!
receiveFromSatellite: aByteArray 
	packages add: aByteArray! !

!SatelliteControllerRadioStub methodsFor: 'messaging' stamp: 'EmilianoMenendez 10/24/2013 11:14'!
sendToController: aByteArray 
	controller receive: aByteArray.! !

!SatelliteControllerRadioStub methodsFor: 'messaging' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 10/19/2013 13:40'!
sendToSatellite: aByteArray 
	satellite receive: aByteArray.! !
